
/*PART I - Generating main variables*/

use lfs.data, clear

keep if sex==1 /*replace with sex==2 when running regressions for women*/

/*Predicted Wage*/

reg lrhpay age2-age5 eth2-eth4 mar2 mar3 educ2-educ4 reg2-reg20 child child05 child611 child1216 numchild1-numchild8  pt publ occup1-occup9 sizefm2-sizefm6 ind2-ind10  exper exper2 exper3 exper4 if yearqu>=19971&yearqu<=19984&work==1
predict w1


/*Wage Growth*/
ge expw=exp(w1)
ge w_wgrowth=expw
replace w_wgrowth=expw*aei if yearqu>=19984
ge w=log(w_wgrowth)

/*Predicted household income*/
gen predwkwage=(wkwage/hpay)*w_wgrowth if w_wgrowth<.
ge hhinc=hhinc_tot
replace hhinc=hhinc_tot-wkwage+predwkwage if predwkwage<.


/*WFTC Calculation*/
ge grosswftc=((53.15*hr16)+(11.25*hr30))*child+(25.60*child05)+(25.60*child611)+(25.60*child1216)
replace grosswftc=((59*hr16)+(11.45*hr30))*child+(26*child05)+(26*child611)+(26*child1216) if (yearqu==20011|yearqu==20012|yearqu==20013|yearqu==20014)
replace grosswftc=((62.50*hr16)+(11.65*hr30))*child+(26.45*child05)+(26.45*child611)+(26.45*child1216) if yearqu>=20021 
ge reductwftc=max(((hhinc-91.45)*0.55),0)
replace reductwftc=max(((hhinc-92.90)*0.55),0) if (yearqu==20011|yearqu==20012|yearqu==20013|yearqu==20014)
replace reductwftc=max(((hhinc-94.50)*0.55),0) if yearqu>=20021
ge n=max((grosswftc-reductwftc),0) 

ge wftcrate=n/hhinc


/*Family Credit Calculation*/

ge grossfc=((49.80*hr16)+(11.05*hr30))*child+(15.15*child05)+(20.90*child611)+(25.90*child1216)
ge reductfc=max(((hhinc-80.65)*0.70),0)
ge nfc=max((grossfc-reductfc),0)

ge fcrate=nfc/hhinc


/*Change in generosity*/

ge fc_gen=wftcrate-fcrate


/*Spillover - Industry*/

bysort indsect (yearqu): egen n1ind_m=mean(wftcrate) if n>0&yearqu>=20001&yearqu<=20031

bysort indsect (yearqu):egen n1ind_c=count(n1ind_m) if yearqu>=20001&yearqu<=20031

egen tn1ind_c=count(n1ind_m) if yearqu>=20001&yearqu<=20031


ge n1ind1=(n1ind_m*n1ind_c)/tn1ind_c

bysort indsect (yearqu): egen spill_ind= max(n1ind1)


/*Spillover Education*/


bysort edu (yearqu): egen n1educ_m=mean(wftcrate) if n>0&yearqu>=20001&yearqu<=20031

bysort edu (yearqu):egen n1educ_c=count(n1educ_m) if yearqu>=20001&yearqu<=20031

egen teduc_c=count(n1educ_m) if yearqu>=20001&yearqu<=20031


ge n1edu1=(n1educ_m*n1educ_c)/teduc_c

bysort edu (yearqu): egen spill_edu= max(n1edu1)

save men.dta, replace
*save women.dta, replace
*save all.dta, replace
*****************************************************
/*PART II - Main Tables*/

/*Table 1a*/
bysort indsect: su wftcrate if n>0&year>=20001&year<=20031

/*Table 1b*/
bysort edu: su wftcrate if n>0&year>=20001&year<=20031

/*Table 2 - The Predicted Wage*//*separately for men and women*/

reg lrhpay publ child child05 child611 child1216 age2-age5 eth2-eth4 mar2 mar3 educ2-educ4 reg2-reg20  pt  numchild1-numchild8 occup1-occup9 sizefm2-sizefm6 ind2-ind10  exper exper2 exper3 exper4 if yearqu<=19984&work==1

/*Table 3a and 3b - Descriptive Statistics - Matched*/ /*separately for men and women*/
keep if age>20
bysort yearqu: egen pw5=pctile(w) if w>0, p(5)
bysort yearqu: egen pw10=pctile(w) if w>0, p(10)
bysort yearqu: egen pw15=pctile(w) if w>0, p(15)
bysort yearqu: egen pw20=pctile(w) if w>0, p(20)
bysort yearqu: egen pw25=pctile(w) if w>0, p(25)
bysort yearqu: egen pw30=pctile(w) if w>0, p(30)

/*w 5-10%*/
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n==0&work==1&yearqu>=19981&yearqu<=19984&w>=pw5&w<=pw10
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n~=0&work==1&yearqu>=19981&yearqu<=19984&w>=pw5&w<=pw10
/*w 10-15%*/
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n==0&work==1&yearqu>=19981&yearqu<=19984&w>=pw10&w<=pw15
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n~=0&work==1&yearqu>=19981&yearqu<=19984&w>=pw10&w<=pw15

/*w 15-20%*/
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n==0&work==1&yearqu>=19981&yearqu<=19984&w>=pw15&w<=pw20
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n~=0&work==1&yearqu>=19981&yearqu<=19984&w>=pw15&w<=pw20

/*w20-25%*/
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n==0&work==1&yearqu>=19981&yearqu<=19984&w>=pw20&w<=pw25
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n~=0&work==1&yearqu>=19981&yearqu<=19984&w>=pw20&w<=pw25

/*w 25-30%*/
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n==0&work==1&yearqu>=19981&yearqu<=19984&w>=pw25&w<=pw30
su age eth1 educ4 publ nmpno tenuremth exper mar1 hours child if n~=0&work==1&yearqu>=19981&yearqu<=19984&w>=pw25&w<=pw30

/*Table 4 - Descriptive Statistics - Unmatched*/ 
use all.dta
su age eth1  educ4 publ tenuremth exper mar1 hours lrhpay s_firm m_firm l_firm if n==0&work==1&yearqu>19972&yearqu<=19982
su age eth1  educ4 publ tenuremth exper mar1 hours lrhpay s_firm m_firm l_firm if n==0&work==1&yearqu>20002&yearqu<=20012
su age eth1  educ4 publ tenuremth exper mar1 hours lrhpay s_firm m_firm l_firm if n~=0&work==1&yearqu>19972&yearqu<=19982
su age eth1  educ4 publ tenuremth exper mar1 hours lrhpay s_firm m_firm l_firm if n~=0&work==1&yearqu>20002&yearqu<=20012


/*Tables 5 & 6 - Effect of WFTC on Wage*/ /*separately for men and women*/
reg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031, vce(bootstrap, rep(200) saving(bsreg7,replace))

reg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031&(marstt==1|marstt==4|marstt==5), vce(bootstrap, rep(200) saving(bsreg7,replace))

reg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031 & (marstt==2|marstt==3), vce(bootstrap, rep(200) saving(bsreg7,replace))

qui qreg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031 ,qu(0.5)
predict xb1
qreg lrhpay w wftcrate fc_gen spill_ind spill_edu yrq*,qu(0.5),if yearqu>=20001&yearqu<=20031& xb1>1.28

qui qreg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031 &(marstt==1|marstt==4|marstt==5) ,qu(0.5)
predict xb1
qreg lrhpay w wftcrate fc_gen spill_ind spill_edu yrq*,qu(0.5),if yearqu>=20001&yearqu<=20031& (marstt==1|marstt==4|marstt==5)& xb1>1.28

qui qreg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031 &(marstt==2|marstt==3) ,qu(0.5)
predict xb1
qreg lrhpay w wftcrate fc_gen spill_ind spill_edu yrq*,qu(0.5),if yearqu>=20001&yearqu<=20031& (marstt==2|marstt==3)& xb1>1.28

/*Table 7 - Falsification Test*//*separately for men and women*/

*Keep if yearqus 1995-1997
*Repeat PART I

reg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if  yearqu>=19961&yearqu<=19964, vce(bootstrap, rep(200) saving(bsreg7,replace))

reg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if  yearqu>=19961&yearqu<=19972, vce(bootstrap, rep(200) saving(bsreg7,replace))


/*Table 8 - Exclude WFTC announcement and implementation*//*separately for men and women*/

*Exclude last two quarters of 1998 and all of 1999
*Repeat PART I

reg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031, vce(bootstrap, rep(200) saving(bsreg7,replace))


/*Table 9 - Firm Size*//*separately for men and women*/

reg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031&(nmpno==1|nmpno==2), vce(bootstrap, rep(200) saving(bsreg7,replace))

reg lrhpay w  wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031&(nmpno==3|nmpno==4|nmpno==5), vce(bootstrap, rep(200) saving(bsreg7,replace))

reg lrhpay w wftcrate fc_gen spill_ind spill_edu yrq* if yearqu>=20001&yearqu<=20031&(nmpno==6|nmpno==7), vce(bootstrap, rep(200) saving(bsreg7,replace))

